@@ -57,8 +57,8 @@
 #define MINUTE_INTERVAL	60000
 #define MIN_WIDTH	   32
 #define MIN_HEIGHT	   32
-#define MAX_WIDTH	 1024
-#define MAX_HEIGHT	 1024
+#define MAX_WIDTH	 1023
+#define MAX_HEIGHT	 1023
 #define MIN_REFRESH_RATE    1
 #define MAX_REFRESH_RATE   60
 
@@ -155,7 +155,7 @@ guint		  g_iuIntervalHandlerId	 = 0;
 gint		  g_iThemeCounter	 = 0;
 GList*		  g_pThemeList		 = NULL;
 gchar		  g_acAppName[]		 = "MacSlow's Cairo-Clock";
-gchar		  g_acAppVersion[]	 = "0.3.3";
+gchar		  g_acAppVersion[]	 = "0.3.4";
 gboolean	  g_bNeedsUpdate	 = TRUE;
 cairo_surface_t*  g_pBackgroundSurface	 = NULL;
 cairo_surface_t*  g_pForegroundSurface	 = NULL;
@@ -173,6 +173,22 @@ update_input_shape (GtkWidget* pWindow,
 		    gint       iWidth,
 		    gint       iHeight);
 
+static gboolean
+is_power_of_two (gint iValue)
+{
+	gint	 iExponent = 0;
+	gboolean bResult   = FALSE;
+
+	for (iExponent = 1; iExponent <= 32; iExponent++)
+		if ((unsigned long) iValue - (1L << iExponent) == 0)
+		{
+			bResult = TRUE;
+			break;
+		}
+
+	return bResult;
+}
+
 static void
 on_info_close (GtkDialog* pDialog,
 	       gpointer   data)
@@ -646,6 +662,12 @@ on_height_value_changed (GtkSpinButton*	pSpinButton,
 	gtk_window_get_size (GTK_WINDOW (window), &iWidth, &iOldHeight);
 	iNewHeight = gtk_spin_button_get_value_as_int (pSpinButton);
 
+	if (is_power_of_two (iNewHeight))
+	{
+		iNewHeight +=1;
+		gtk_spin_button_set_value (pSpinButton, (gdouble) iNewHeight);
+	}
+
 	if (iOldHeight != iNewHeight)
 	{
 		gtk_window_resize (GTK_WINDOW (window), iWidth, iNewHeight);
@@ -665,6 +687,12 @@ on_width_value_changed (GtkSpinButton* pSpinButton,
 	gtk_window_get_size (GTK_WINDOW (window), &iOldWidth, &iHeight);
 	iNewWidth = gtk_spin_button_get_value_as_int (pSpinButton);
 
+	if (is_power_of_two (iNewWidth))
+	{
+		iNewWidth +=1;
+		gtk_spin_button_set_value (pSpinButton, (gdouble) iNewWidth);
+	}
+
 	if (iOldWidth != iNewWidth)
 	{
 		gtk_window_resize (GTK_WINDOW (window), iNewWidth, iHeight);
@@ -1395,14 +1423,6 @@ main (int    argc,
 		    g_iDefaultY >= gdk_screen_get_height (gdk_screen_get_default ()))
 			g_iDefaultY = 0;
 
-		if (g_iDefaultWidth <= MIN_WIDTH ||
-		    g_iDefaultWidth >= MAX_WIDTH)
-			g_iDefaultWidth = 100;
-
-		if (g_iDefaultHeight <= MIN_HEIGHT ||
-		    g_iDefaultHeight >= MAX_HEIGHT)
-			g_iDefaultHeight = 100;
-
 		if (g_iRefreshRate <= MIN_REFRESH_RATE ||
 		    g_iRefreshRate >= MAX_REFRESH_RATE)
 			g_iRefreshRate = 30;
@@ -1428,6 +1448,20 @@ main (int    argc,
 			free (pcFilename);
 	}
 
+	if (g_iDefaultWidth <= MIN_WIDTH ||
+	    g_iDefaultWidth >= MAX_WIDTH)
+		g_iDefaultWidth = 100;
+
+	if (is_power_of_two (g_iDefaultWidth))
+		g_iDefaultWidth += 1;
+
+	if (g_iDefaultHeight <= MIN_HEIGHT ||
+	    g_iDefaultHeight >= MAX_HEIGHT)
+		g_iDefaultHeight = 100;
+
+	if (is_power_of_two (g_iDefaultHeight))
+		g_iDefaultHeight += 1;
+
 	if (bPrintVersion)
 	{
 		printf ("%s %s\n", g_acAppName, g_acAppVersion);
